Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the infra.io v1 API group +kubebuilder:object:generate=true +groupName=infra.io.odimra
Index ¶
- Variables
- type ArrayControllers
- type AuthDetails
- type BMC
- type BiosSchemaRegistry
- type BiosSchemaRegistryList
- type BiosSchemaRegistrySpec
- type BiosSchemaRegistryStatus
- type BiosSetting
- type BiosSettingList
- type BiosSettingSpec
- type BiosSettingStatus
- type Bmc
- type BmcList
- type BmcSpec
- type BmcStatus
- type BootOrderSetting
- type BootOrderSettingList
- type BootOrderSettingsSpec
- type BootOrderSettingsStatus
- type BootSetting
- type Credential
- type DriveDetails
- type EventMessage
- type EventsMessageRegistry
- type EventsMessageRegistryList
- type EventsMessageRegistrySpec
- type EventsMessageRegistryStatus
- type Eventsubscription
- type EventsubscriptionList
- type EventsubscriptionSpec
- type EventsubscriptionStatus
- type Firmware
- type FirmwareList
- type FirmwareSpec
- type FirmwareStatus
- type Identifier
- type ImageDetails
- type Odim
- type OdimList
- type OdimSpec
- type OdimStatus
- type Oem
- type State
- type SupportedSystems
- type SystemDetail
- type Volume
- type VolumeList
- type VolumeSpec
- type VolumeStatus
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "infra.io.odimra", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var AllowableResetValues = map[SystemDetail][]string{
{"HPE", "ProLiant DL380 Gen10 Plus"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"HPE", "ProLiant DL380 Gen10"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"HPE", "ProLiant DL360 Gen10"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"HPE", "ProLiant DL360 Gen10 Plus"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"HPE", "ProLiant DL385 Gen10"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"HPE", "ProLiant e910"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"HPE", "ProLiant DL110 Gen10 Plus"}: {"On", "ForceOff", "GracefulShutdown", "ForceRestart", "Nmi", "PushPowerButton", "GracefulRestart"},
{"DELL", "PowerEdge R440"}: {"On", "ForceOff", "ForceRestart", "GracefulShutdown", "PushPowerButton", "Nmi", "PowerCycle"},
{"LENOVO", "ThinkSystem SR630"}: {"On", "Nmi", "GracefulShutdown", "GracefulRestart", "ForceOn", "ForceOff", "ForceRestart"},
}
AllowableResetValues defines allowable reset values for a bmc
var ResetWhenOffOff = map[State]bool{ {"OFF", "OFF", "ForceRestart"}: false, {"OFF", "OFF", "GracefulRestart"}: false, {"OFF", "OFF", "GracefulShutdown"}: false, {"OFF", "OFF", "ForceOff"}: false, {"OFF", "OFF", "On"}: false, {"OFF", "OFF", "Pause"}: false, {"OFF", "OFF", "Resume"}: false, {"OFF", "OFF", "ForceOn"}: false, {"OFF", "OFF", "Nmi"}: false, {"OFF", "OFF", "PowerCycle"}: false, {"OFF", "OFF", "PushPowerButton"}: false, {"OFF", "OFF", "Suspend"}: false, }
ResetWhenOffOff map defines if reset can be applied on bmc based on different state
var ResetWhenOffOn = map[State]bool{ {"OFF", "ON", "ForceRestart"}: false, {"OFF", "ON", "GracefulRestart"}: false, {"OFF", "ON", "GracefulShutdown"}: false, {"OFF", "ON", "ForceOff"}: false, {"OFF", "ON", "On"}: true, {"OFF", "ON", "Pause"}: false, {"OFF", "ON", "Resume"}: false, {"OFF", "ON", "ForceOn"}: true, {"OFF", "ON", "Nmi"}: false, {"OFF", "ON", "PowerCycle"}: true, {"OFF", "ON", "PushPowerButton"}: true, {"OFF", "ON", "Suspend"}: false, }
ResetWhenOffOn map defines if reset can be applied on bmc based on different state
var ResetWhenOnOff = map[State]bool{ {"ON", "OFF", "ForceRestart"}: false, {"ON", "OFF", "GracefulRestart"}: false, {"ON", "OFF", "GracefulShutdown"}: true, {"ON", "OFF", "ForceOff"}: true, {"ON", "OFF", "On"}: false, {"ON", "OFF", "Pause"}: true, {"ON", "OFF", "Resume"}: false, {"ON", "OFF", "ForceOn"}: false, {"ON", "OFF", "Nmi"}: false, {"ON", "OFF", "PowerCycle"}: false, {"ON", "OFF", "PushPowerButton"}: true, {"ON", "OFF", "Suspend"}: true, }
ResetWhenOnOff map defines if reset can be applied on bmc based on different state
var ResetWhenOnOn = map[State]bool{ {"ON", "ON", "ForceRestart"}: true, {"ON", "ON", "GracefulRestart"}: true, {"ON", "ON", "GracefulShutdown"}: false, {"ON", "ON", "ForceOff"}: false, {"ON", "ON", "On"}: false, {"ON", "ON", "Pause"}: true, {"ON", "ON", "Resume"}: false, {"ON", "ON", "ForceOn"}: false, {"ON", "ON", "Nmi"}: true, {"ON", "ON", "PowerCycle"}: true, {"ON", "ON", "PushPowerButton"}: false, {"ON", "ON", "Suspend"}: true, }
ResetWhenOnOn map defines if reset can be applied on bmc based on different state
var Vendor = []string{"HPE", "DELL", "LENOVO"}
Vendor defines supportable vendors
Functions ¶
This section is empty.
Types ¶
type ArrayControllers ¶
type ArrayControllers struct {
SupportedRAIDLevel []string `json:"supportedRAIDLevel"`
Drives map[string]DriveDetails `json:"drives"`
}
ArrayControllers defines the storage controllers for BMC
func (*ArrayControllers) DeepCopy ¶
func (in *ArrayControllers) DeepCopy() *ArrayControllers
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ArrayControllers.
func (*ArrayControllers) DeepCopyInto ¶
func (in *ArrayControllers) DeepCopyInto(out *ArrayControllers)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AuthDetails ¶
type AuthDetails struct {
Password string `json:"password,omitempty"`
Username string `json:"username,omitempty"`
}
AuthDetails struct contains information required for authentication
func (*AuthDetails) DeepCopy ¶
func (in *AuthDetails) DeepCopy() *AuthDetails
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AuthDetails.
func (*AuthDetails) DeepCopyInto ¶
func (in *AuthDetails) DeepCopyInto(out *AuthDetails)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BMC ¶
type BMC struct {
Address string `json:"address"`
ConnMethVariant string `json:"connectionMethodVariant"`
PowerState string `json:"powerState"`
ResetType string `json:"resetType"`
}
BMC defines a struct to hold basic properties of a BMC
func (*BMC) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BMC.
func (*BMC) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BiosSchemaRegistry ¶
type BiosSchemaRegistry struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec BiosSchemaRegistrySpec `json:"spec,omitempty"`
Status BiosSchemaRegistryStatus `json:"status,omitempty"`
}
BiosSchemaRegistry is the Schema for the biosschemaregistries API
func (*BiosSchemaRegistry) DeepCopy ¶
func (in *BiosSchemaRegistry) DeepCopy() *BiosSchemaRegistry
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSchemaRegistry.
func (*BiosSchemaRegistry) DeepCopyInto ¶
func (in *BiosSchemaRegistry) DeepCopyInto(out *BiosSchemaRegistry)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BiosSchemaRegistry) DeepCopyObject ¶
func (in *BiosSchemaRegistry) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BiosSchemaRegistryList ¶
type BiosSchemaRegistryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []BiosSchemaRegistry `json:"items"`
}
BiosSchemaRegistryList contains a list of BiosSchemaRegistry
func (*BiosSchemaRegistryList) DeepCopy ¶
func (in *BiosSchemaRegistryList) DeepCopy() *BiosSchemaRegistryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSchemaRegistryList.
func (*BiosSchemaRegistryList) DeepCopyInto ¶
func (in *BiosSchemaRegistryList) DeepCopyInto(out *BiosSchemaRegistryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BiosSchemaRegistryList) DeepCopyObject ¶
func (in *BiosSchemaRegistryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BiosSchemaRegistrySpec ¶
type BiosSchemaRegistrySpec struct {
Name string `json:"Name,omitempty"`
ID string `json:"ID,omitempty"`
OwningEntity string `json:"OwningEntity,omitempty"`
RegistryVersion string `json:"RegistryVersion,omitempty"`
Attributes []map[string]string `json:"Attributes,omitempty"`
SupportedSystems []SupportedSystems `json:"SupportedSystems,omitempty"`
}
BiosSchemaRegistrySpec defines the desired state of BiosSchemaRegistry
func (*BiosSchemaRegistrySpec) DeepCopy ¶
func (in *BiosSchemaRegistrySpec) DeepCopy() *BiosSchemaRegistrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSchemaRegistrySpec.
func (*BiosSchemaRegistrySpec) DeepCopyInto ¶
func (in *BiosSchemaRegistrySpec) DeepCopyInto(out *BiosSchemaRegistrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BiosSchemaRegistryStatus ¶
type BiosSchemaRegistryStatus struct {
}
BiosSchemaRegistryStatus defines the observed state of BiosSchemaRegistry
func (*BiosSchemaRegistryStatus) DeepCopy ¶
func (in *BiosSchemaRegistryStatus) DeepCopy() *BiosSchemaRegistryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSchemaRegistryStatus.
func (*BiosSchemaRegistryStatus) DeepCopyInto ¶
func (in *BiosSchemaRegistryStatus) DeepCopyInto(out *BiosSchemaRegistryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BiosSetting ¶
type BiosSetting struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec BiosSettingSpec `json:"spec,omitempty"`
Status BiosSettingStatus `json:"status,omitempty"`
}
BiosSetting is the Schema for the biossettings API
func (*BiosSetting) DeepCopy ¶
func (in *BiosSetting) DeepCopy() *BiosSetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSetting.
func (*BiosSetting) DeepCopyInto ¶
func (in *BiosSetting) DeepCopyInto(out *BiosSetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BiosSetting) DeepCopyObject ¶
func (in *BiosSetting) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BiosSettingList ¶
type BiosSettingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []BiosSetting `json:"items"`
}
BiosSettingList contains a list of BiosSetting
func (*BiosSettingList) DeepCopy ¶
func (in *BiosSettingList) DeepCopy() *BiosSettingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSettingList.
func (*BiosSettingList) DeepCopyInto ¶
func (in *BiosSettingList) DeepCopyInto(out *BiosSettingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BiosSettingList) DeepCopyObject ¶
func (in *BiosSettingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BiosSettingSpec ¶
type BiosSettingSpec struct {
BmcName string `json:"bmcName,omitempty"`
SystemID string `json:"systemID,omitempty"`
SerialNo string `json:"serialNumber,omitempty"`
Bios map[string]string `json:"biosAttributes"`
}
BiosSettingSpec defines the desired state of BiosSetting
func (*BiosSettingSpec) DeepCopy ¶
func (in *BiosSettingSpec) DeepCopy() *BiosSettingSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSettingSpec.
func (*BiosSettingSpec) DeepCopyInto ¶
func (in *BiosSettingSpec) DeepCopyInto(out *BiosSettingSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BiosSettingStatus ¶
BiosSettingStatus defines the observed state of BiosSetting
func (*BiosSettingStatus) DeepCopy ¶
func (in *BiosSettingStatus) DeepCopy() *BiosSettingStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BiosSettingStatus.
func (*BiosSettingStatus) DeepCopyInto ¶
func (in *BiosSettingStatus) DeepCopyInto(out *BiosSettingStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Bmc ¶
type Bmc struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec BmcSpec `json:"spec,omitempty"`
Status BmcStatus `json:"status,omitempty"`
}
Bmc is the Schema for the bmcs API +kubebuilder:printcolumn:name="SystemID",type="string",JSONPath=".status.bmcSystemId" +kubebuilder:printcolumn:name="SerialNumber",type="string",JSONPath=".status.serialNumber" +kubebuilder:printcolumn:name="Vendor",type="string",JSONPath=".status.vendorName" +kubebuilder:printcolumn:name="ModelID",type="string",JSONPath=".status.modelID" +kubebuilder:printcolumn:name="FirmwareVersion",type="string",JSONPath=".status.firmwareVersion" +kubebuilder:printcolumn:name="Age",type="date",JSONPath=".metadata.creationTimestamp"
func (*Bmc) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Bmc.
func (*Bmc) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Bmc) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BmcList ¶
type BmcList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Bmc `json:"items"`
}
BmcList contains a list of Bmc
func (*BmcList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BmcList.
func (*BmcList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BmcList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BmcSpec ¶
type BmcSpec struct {
BmcDetails BMC `json:"bmc"`
Credentials Credential `json:"credentials,omitempty"`
}
BmcSpec defines the desired state of Bmc
func (*BmcSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BmcSpec.
func (*BmcSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BmcStatus ¶
type BmcStatus struct {
BmcAddStatus string `json:"bmcAddStatus"`
BmcSystemID string `json:"bmcSystemId"`
SerialNumber string `json:"serialNumber"`
VendorName string `json:"vendorName"`
ModelID string `json:"modelID"`
FirmwareVersion string `json:"firmwareVersion"`
BiosVersion string `json:"biosVersion"`
BiosAttributeRegistry string `json:"biosAttributeRegistry"`
EventsMessageRegistry string `json:"eventsMessageRegistry,omitempty"`
StorageControllers map[string]ArrayControllers `json:"storageControllers,omitempty"`
SystemReset string `json:"systemReset"`
PowerState string `json:"powerState"`
}
BmcStatus defines the observed state of Bmc
func (*BmcStatus) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BmcStatus.
func (*BmcStatus) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BootOrderSetting ¶
type BootOrderSetting struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec BootOrderSettingsSpec `json:"spec,omitempty"`
Status BootOrderSettingsStatus `json:"status,omitempty"`
}
BootOrderSetting is the Schema for the bootordersetting API
func (*BootOrderSetting) DeepCopy ¶
func (in *BootOrderSetting) DeepCopy() *BootOrderSetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BootOrderSetting.
func (*BootOrderSetting) DeepCopyInto ¶
func (in *BootOrderSetting) DeepCopyInto(out *BootOrderSetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BootOrderSetting) DeepCopyObject ¶
func (in *BootOrderSetting) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BootOrderSettingList ¶
type BootOrderSettingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []BootOrderSetting `json:"items"`
}
BootOrderSettingList contains a list of BootOrderSettings
func (*BootOrderSettingList) DeepCopy ¶
func (in *BootOrderSettingList) DeepCopy() *BootOrderSettingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BootOrderSettingList.
func (*BootOrderSettingList) DeepCopyInto ¶
func (in *BootOrderSettingList) DeepCopyInto(out *BootOrderSettingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BootOrderSettingList) DeepCopyObject ¶
func (in *BootOrderSettingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BootOrderSettingsSpec ¶
type BootOrderSettingsSpec struct {
BmcName string `json:"bmcName,omitempty"`
SystemID string `json:"systemID,omitempty"`
SerialNo string `json:"serialNumber,omitempty"`
Boot *BootSetting `json:"boot,omitempty"`
}
BootOrderSettingsSpec defines the desired state of BootOrderSettings
func (*BootOrderSettingsSpec) DeepCopy ¶
func (in *BootOrderSettingsSpec) DeepCopy() *BootOrderSettingsSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BootOrderSettingsSpec.
func (*BootOrderSettingsSpec) DeepCopyInto ¶
func (in *BootOrderSettingsSpec) DeepCopyInto(out *BootOrderSettingsSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BootOrderSettingsStatus ¶
type BootOrderSettingsStatus struct {
Boot BootSetting `json:"boot,omitempty"`
}
BootOrderSettingsStatus defines the observed state of BootOrderSettings
func (*BootOrderSettingsStatus) DeepCopy ¶
func (in *BootOrderSettingsStatus) DeepCopy() *BootOrderSettingsStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BootOrderSettingsStatus.
func (*BootOrderSettingsStatus) DeepCopyInto ¶
func (in *BootOrderSettingsStatus) DeepCopyInto(out *BootOrderSettingsStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BootSetting ¶
type BootSetting struct {
BootOrder []string `json:"bootOrder,omitempty"`
BootSourceOverrideEnabled string `json:"bootSourceOverrideEnabled,omitempty"`
BootSourceOverrideMode string `json:"bootSourceOverrideMode,omitempty"`
BootSourceOverrideTarget string `json:"bootSourceOverrideTarget,omitempty"`
BootTargetAllowableValues []string `json:"bootSourceOverrideTarget.AllowableValues,omitempty"`
UefiTargetBootSourceOverride string `json:"uefiTargetBootSourceOverride,omitempty"`
UefiTargetAllowableValues []string `json:"uefiTargetBootSourceOverride.AllowableValues,omitempty"`
}
BootSetting defines the different settings for boot
func (*BootSetting) DeepCopy ¶
func (in *BootSetting) DeepCopy() *BootSetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BootSetting.
func (*BootSetting) DeepCopyInto ¶
func (in *BootSetting) DeepCopyInto(out *BootSetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Credential ¶
Credential struct holds username and password for the BMC
func (*Credential) DeepCopy ¶
func (in *Credential) DeepCopy() *Credential
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Credential.
func (*Credential) DeepCopyInto ¶
func (in *Credential) DeepCopyInto(out *Credential)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DriveDetails ¶
type DriveDetails struct {
CapacityBytes string `json:"capacityBytes"`
UsedInVolumes []int `json:"usedInVolumes"`
}
DriveDetails defines the drive details for specific Array Controller
func (*DriveDetails) DeepCopy ¶
func (in *DriveDetails) DeepCopy() *DriveDetails
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DriveDetails.
func (*DriveDetails) DeepCopyInto ¶
func (in *DriveDetails) DeepCopyInto(out *DriveDetails)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventMessage ¶
type EventMessage struct {
Description string `json:"Description,omitempty"`
Message string `json:"Message,omitempty"`
NumberOfArgs string `json:"NumberOfArgs,omitempty"`
Oem map[string]Oem `json:"Oem,omitempty"`
ParamTypes []string `json:"ParamTypes,omitempty"`
Resolution string `json:"Resolution,omitempty"`
Severity string `json:"Severity,omitempty"`
}
EventMessage defines the message struct
func (*EventMessage) DeepCopy ¶
func (in *EventMessage) DeepCopy() *EventMessage
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventMessage.
func (*EventMessage) DeepCopyInto ¶
func (in *EventMessage) DeepCopyInto(out *EventMessage)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventsMessageRegistry ¶
type EventsMessageRegistry struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EventsMessageRegistrySpec `json:"spec,omitempty"`
Status EventsMessageRegistryStatus `json:"status,omitempty"`
}
EventsMessageRegistry is the Schema for the eventsmessageregistries API
func (*EventsMessageRegistry) DeepCopy ¶
func (in *EventsMessageRegistry) DeepCopy() *EventsMessageRegistry
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsMessageRegistry.
func (*EventsMessageRegistry) DeepCopyInto ¶
func (in *EventsMessageRegistry) DeepCopyInto(out *EventsMessageRegistry)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventsMessageRegistry) DeepCopyObject ¶
func (in *EventsMessageRegistry) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventsMessageRegistryList ¶
type EventsMessageRegistryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EventsMessageRegistry `json:"items"`
}
EventsMessageRegistryList contains a list of EventsMessageRegistry
func (*EventsMessageRegistryList) DeepCopy ¶
func (in *EventsMessageRegistryList) DeepCopy() *EventsMessageRegistryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsMessageRegistryList.
func (*EventsMessageRegistryList) DeepCopyInto ¶
func (in *EventsMessageRegistryList) DeepCopyInto(out *EventsMessageRegistryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventsMessageRegistryList) DeepCopyObject ¶
func (in *EventsMessageRegistryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventsMessageRegistrySpec ¶
type EventsMessageRegistrySpec struct {
Name string `json:"Name,omitempty"`
ID string `json:"ID,omitempty"`
OwningEntity string `json:"OwningEntity,omitempty"`
RegistryVersion string `json:"RegistryVersion,omitempty"`
RegistryPrefix string `json:"RegistryPrefix,omitempty"`
Messages map[string]EventMessage `json:"Messages,omitempty"`
}
EventsMessageRegistrySpec defines the desired state of EventsMessageRegistry
func (*EventsMessageRegistrySpec) DeepCopy ¶
func (in *EventsMessageRegistrySpec) DeepCopy() *EventsMessageRegistrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsMessageRegistrySpec.
func (*EventsMessageRegistrySpec) DeepCopyInto ¶
func (in *EventsMessageRegistrySpec) DeepCopyInto(out *EventsMessageRegistrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventsMessageRegistryStatus ¶
type EventsMessageRegistryStatus struct {
}
EventsMessageRegistryStatus defines the observed state of EventsMessageRegistry
func (*EventsMessageRegistryStatus) DeepCopy ¶
func (in *EventsMessageRegistryStatus) DeepCopy() *EventsMessageRegistryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsMessageRegistryStatus.
func (*EventsMessageRegistryStatus) DeepCopyInto ¶
func (in *EventsMessageRegistryStatus) DeepCopyInto(out *EventsMessageRegistryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Eventsubscription ¶
type Eventsubscription struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EventsubscriptionSpec `json:"spec,omitempty"`
Status EventsubscriptionStatus `json:"status,omitempty"`
}
Eventsubscription is the Schema for the eventsubscriptions API +kubebuilder:printcolumn:name="EventSubscriptionID",type="string",JSONPath=".status.eventSubscriptionID" +kubebuilder:printcolumn:name="Destination",type="string",JSONPath=".status.destination" +kubebuilder:printcolumn:name="Context",type="string",JSONPath=".status.context" +kubebuilder:printcolumn:name="SubscriptionType",type="string",JSONPath=".status.subscriptionType"
func (*Eventsubscription) DeepCopy ¶
func (in *Eventsubscription) DeepCopy() *Eventsubscription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Eventsubscription.
func (*Eventsubscription) DeepCopyInto ¶
func (in *Eventsubscription) DeepCopyInto(out *Eventsubscription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Eventsubscription) DeepCopyObject ¶
func (in *Eventsubscription) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventsubscriptionList ¶
type EventsubscriptionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Eventsubscription `json:"items"`
}
EventsubscriptionList contains a list of Eventsubscription
func (*EventsubscriptionList) DeepCopy ¶
func (in *EventsubscriptionList) DeepCopy() *EventsubscriptionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsubscriptionList.
func (*EventsubscriptionList) DeepCopyInto ¶
func (in *EventsubscriptionList) DeepCopyInto(out *EventsubscriptionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventsubscriptionList) DeepCopyObject ¶
func (in *EventsubscriptionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventsubscriptionSpec ¶
type EventsubscriptionSpec struct {
Name string `json:"name,omitempty"`
Destination string `json:"destination"`
EventTypes []string `json:"eventTypes,omitempty"`
MessageIds []string `json:"messageIds,omitempty"`
ResourceTypes []string `json:"resourceTypes,omitempty"`
Context string `json:"context"`
EventFormatType string `json:"eventFormatType,omitempty"`
SubordinateResources bool `json:"subordinateResources,omitempty"`
OriginResources []string `json:"originResources,omitempty"`
}
EventsubscriptionSpec defines the desired state of Eventsubscription
func (*EventsubscriptionSpec) DeepCopy ¶
func (in *EventsubscriptionSpec) DeepCopy() *EventsubscriptionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsubscriptionSpec.
func (*EventsubscriptionSpec) DeepCopyInto ¶
func (in *EventsubscriptionSpec) DeepCopyInto(out *EventsubscriptionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EventsubscriptionStatus ¶
type EventsubscriptionStatus struct {
ID string `json:"eventSubscriptionID"`
Name string `json:"name,omitempty"`
Destination string `json:"destination"`
Context string `json:"context"`
Protocol string `json:"protocol"`
EventTypes []string `json:"eventTypes,omitempty"`
MessageIds []string `json:"messageIds,omitempty"`
SubscriptionType string `json:"subscriptionType"`
ResourceTypes []string `json:"resourceTypes,omitempty"`
OriginResources []string `json:"originResources,omitempty"`
}
EventsubscriptionStatus defines the observed state of Eventsubscription
func (*EventsubscriptionStatus) DeepCopy ¶
func (in *EventsubscriptionStatus) DeepCopy() *EventsubscriptionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventsubscriptionStatus.
func (*EventsubscriptionStatus) DeepCopyInto ¶
func (in *EventsubscriptionStatus) DeepCopyInto(out *EventsubscriptionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Firmware ¶
type Firmware struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec FirmwareSpec `json:"spec,omitempty"`
Status FirmwareStatus `json:"status,omitempty"`
}
Firmware is the Schema for the firmwares API
func (*Firmware) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Firmware.
func (*Firmware) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Firmware) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FirmwareList ¶
type FirmwareList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Firmware `json:"items"`
}
FirmwareList contains a list of Firmware
func (*FirmwareList) DeepCopy ¶
func (in *FirmwareList) DeepCopy() *FirmwareList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FirmwareList.
func (*FirmwareList) DeepCopyInto ¶
func (in *FirmwareList) DeepCopyInto(out *FirmwareList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*FirmwareList) DeepCopyObject ¶
func (in *FirmwareList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FirmwareSpec ¶
type FirmwareSpec struct {
Image ImageDetails `json:"image"`
TransferProtocol string `json:"transferProtocol,omitempty"`
}
FirmwareSpec defines the desired state of Firmware
func (*FirmwareSpec) DeepCopy ¶
func (in *FirmwareSpec) DeepCopy() *FirmwareSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FirmwareSpec.
func (*FirmwareSpec) DeepCopyInto ¶
func (in *FirmwareSpec) DeepCopyInto(out *FirmwareSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FirmwareStatus ¶
type FirmwareStatus struct {
Status string `json:"status,omitempty"`
FirmwareVersion string `json:"firmwareVersion,omitempty"`
ImagePath string `json:"imagePath,omitempty"`
}
FirmwareStatus defines the observed state of Firmware
func (*FirmwareStatus) DeepCopy ¶
func (in *FirmwareStatus) DeepCopy() *FirmwareStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FirmwareStatus.
func (*FirmwareStatus) DeepCopyInto ¶
func (in *FirmwareStatus) DeepCopyInto(out *FirmwareStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Identifier ¶
type Identifier struct {
DurableName string `json:"DurableName"`
DurableNameFormat string `json:"DurableNameFormat"`
}
func (*Identifier) DeepCopy ¶
func (in *Identifier) DeepCopy() *Identifier
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Identifier.
func (*Identifier) DeepCopyInto ¶
func (in *Identifier) DeepCopyInto(out *Identifier)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ImageDetails ¶
type ImageDetails struct {
ImageLocation string `json:"imageLocation"`
Auth AuthDetails `json:"auth,omitempty"`
}
ImageDetails holds information for firmware image
func (*ImageDetails) DeepCopy ¶
func (in *ImageDetails) DeepCopy() *ImageDetails
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ImageDetails.
func (*ImageDetails) DeepCopyInto ¶
func (in *ImageDetails) DeepCopyInto(out *ImageDetails)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Odim ¶
type Odim struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec OdimSpec `json:"spec,omitempty"`
Status OdimStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:subresource:status Odim is the Schema for the odims API +kubebuilder:printcolumn:name="URL",type="string",JSONPath=".spec.URL" +kubebuilder:printcolumn:name="Status",type="string",JSONPath=".status.status" +kubebuilder:printcolumn:name="Age",type="date",JSONPath=".metadata.creationTimestamp"
func (*Odim) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Odim.
func (*Odim) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Odim) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type OdimList ¶
type OdimList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Odim `json:"items"`
}
+kubebuilder:object:root=true OdimList contains a list of Odim
func (*OdimList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OdimList.
func (*OdimList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*OdimList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type OdimSpec ¶
type OdimSpec struct {
URL string `json:"URL"`
EventListenerHost string `json:"EventListenerHost"`
}
OdimSpec defines the desired state of Odim
func (*OdimSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OdimSpec.
func (*OdimSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type OdimStatus ¶
type OdimStatus struct {
Status string `json:"status,omitempty"`
ConnMethVariants map[string]string `json:"connectionMethodVariants,omitempty"`
}
OdimStatus defines the observed state of Odim
func (*OdimStatus) DeepCopy ¶
func (in *OdimStatus) DeepCopy() *OdimStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new OdimStatus.
func (*OdimStatus) DeepCopyInto ¶
func (in *OdimStatus) DeepCopyInto(out *OdimStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Oem ¶
type Oem struct {
OdataType string `json:"odataType,omitempty"`
HealthCategory string `json:"HealthCategory,omitempty"`
Type string `json:"Type,omitempty"`
}
Oem defines the Oem property struct
func (*Oem) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Oem.
func (*Oem) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type State ¶
State defines the state to be applied by user
func (*State) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new State.
func (*State) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SupportedSystems ¶
type SupportedSystems struct {
ProductName string `json:"ProductName,omitempty"`
SystemID string `json:"SystemId,omitempty"`
FirmwareVersion string `json:"FirmwareVersion,omitempty"`
}
SupportedSystems defines all the supported system for schema
func (*SupportedSystems) DeepCopy ¶
func (in *SupportedSystems) DeepCopy() *SupportedSystems
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SupportedSystems.
func (*SupportedSystems) DeepCopyInto ¶
func (in *SupportedSystems) DeepCopyInto(out *SupportedSystems)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SystemDetail ¶
SystemDetail struct defines basic properties of a system
func (*SystemDetail) DeepCopy ¶
func (in *SystemDetail) DeepCopy() *SystemDetail
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SystemDetail.
func (*SystemDetail) DeepCopyInto ¶
func (in *SystemDetail) DeepCopyInto(out *SystemDetail)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Volume ¶
type Volume struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec VolumeSpec `json:"spec,omitempty"`
Status VolumeStatus `json:"status,omitempty"`
}
+kubebuilder:object:root=true +kubebuilder:subresource:status Volume is the Schema for the volumes API +kubebuilder:printcolumn:name="VolumeName",type="string",JSONPath=".status.volumeName" +kubebuilder:printcolumn:name="VolumeID",type="string",JSONPath=".status.volumeID" +kubebuilder:printcolumn:name="RAIDType",type="string",JSONPath=".status.RAIDType" +kubebuilder:printcolumn:name="CapacityBytes",type="string",JSONPath=".status.capacityBytes"
func (*Volume) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Volume.
func (*Volume) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Volume) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VolumeList ¶
type VolumeList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Volume `json:"items"`
}
+kubebuilder:object:root=true VolumeList contains a list of Volume
func (*VolumeList) DeepCopy ¶
func (in *VolumeList) DeepCopy() *VolumeList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VolumeList.
func (*VolumeList) DeepCopyInto ¶
func (in *VolumeList) DeepCopyInto(out *VolumeList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VolumeList) DeepCopyObject ¶
func (in *VolumeList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VolumeSpec ¶
type VolumeSpec struct {
StorageControllerID string `json:"storageControllerID,omitempty"`
RAIDType string `json:"RAIDType,omitempty"`
Drives []int `json:"drives,omitempty"`
}
VolumeSpec defines the desired state of Volume +kubebuilder:validation:XPreserveUnknownFields
func (*VolumeSpec) DeepCopy ¶
func (in *VolumeSpec) DeepCopy() *VolumeSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VolumeSpec.
func (*VolumeSpec) DeepCopyInto ¶
func (in *VolumeSpec) DeepCopyInto(out *VolumeSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VolumeStatus ¶
type VolumeStatus struct {
VolumeID string `json:"volumeID"`
VolumeName string `json:"volumeName"`
RAIDType string `json:"RAIDType"`
StorageControllerID string `json:"storageControllerID"`
Drives []int `json:"drives"`
CapacityBytes string `json:"capacityBytes"`
Identifiers Identifier `json:"Identifiers"`
}
VolumeStatus defines the observed state of Volume +kubebuilder:validation:XPreserveUnknownFields
func (*VolumeStatus) DeepCopy ¶
func (in *VolumeStatus) DeepCopy() *VolumeStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VolumeStatus.
func (*VolumeStatus) DeepCopyInto ¶
func (in *VolumeStatus) DeepCopyInto(out *VolumeStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.